@@ -44,7 +44,7 @@ mod server;
 
 use std::path::PathBuf;
 
-const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.20/";
+const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.21/";
 
 const CHOMP_INIT: &str = r#"version = 0.1
 
@@ -70,9 +70,9 @@ fn uri_parse(uri_str: &str) -> Option<Uri> {
 #[tokio::main]
 async fn main() -> Result<()> {
     #[cfg(not(debug_assertions))]
-    let version = "0.2.0";
+    let version = "0.2.1";
     #[cfg(debug_assertions)]
-    let version = "0.2.0-debug";
+    let version = "0.2.1-debug";
     let matches = App::new("Chomp")
         .version(version)
         .arg(
@@ -204,11 +204,11 @@ async fn main() -> Result<()> {
 
     let mut created = false;
     let chompfile_source = {
-        let is_file: bool = match fs::metadata(&cfg_file) {
-            Ok(meta) => !meta.is_dir(),
+        let is_dir: bool = match fs::metadata(&cfg_file) {
+            Ok(meta) => meta.is_dir(),
             Err(_) => false
         };
-        if !is_file {
+        if is_dir {
             cfg_file.push("chompfile.toml");
         }
         match fs::read_to_string(&cfg_file) {
@@ -463,6 +463,9 @@ async fn main() -> Result<()> {
     chompfile.task.append(&mut template_tasks);
 
     if matches.is_present("list") {
+        if targets.len() > 0 {
+            return Err(anyhow!("--list does not take any arguments."));
+        }
         if matches.is_present("eject_templates") || matches.is_present("format") || matches.is_present("init") {
             return Err(anyhow!("Cannot use --list with --eject-templates, --format or --init."));
         }
@@ -484,6 +487,7 @@ async fn main() -> Result<()> {
                 }
             }
         }
+        return Ok(());
     }
 
     if matches.is_present("format")
